@@ -15,6 +15,7 @@
 
 """Test module module"""
 
+import sys
 from unittest import mock
 
 from openstackclient.common import module as osc_module
@@ -43,6 +44,7 @@ module_name_5 = '_private_module.lib'
 module_version_5 = '0.0.1'
 
 MODULES = {
+    'sys': sys,
     module_name_1: fakes.FakeModule(module_name_1, module_version_1),
     module_name_2: fakes.FakeModule(module_name_2, module_version_2),
     module_name_3: fakes.FakeModule(module_name_3, module_version_3),
@@ -52,9 +54,8 @@ MODULES = {
 
 
 class TestCommandList(utils.TestCommand):
-
     def setUp(self):
-        super(TestCommandList, self).setUp()
+        super().setUp()
 
         self.app.command_manager = mock.Mock()
         self.app.command_manager.get_command_groups.return_value = [
@@ -81,16 +82,14 @@ class TestCommandList(utils.TestCommand):
         # handling the detection rather than using the hard-code below.
         collist = ('Command Group', 'Commands')
         self.assertEqual(collist, columns)
-        datalist = ((
-            'openstack.common',
-            'limits show\nextension list'
-        ),)
+        datalist = (('openstack.common', 'limits show\nextension list'),)
 
         self.assertEqual(datalist, tuple(data))
 
     def test_command_list_with_group_not_found(self):
         arglist = [
-            '--group', 'not_exist',
+            '--group',
+            'not_exist',
         ]
         verifylist = [
             ('group', 'not_exist'),
@@ -105,7 +104,8 @@ class TestCommandList(utils.TestCommand):
 
     def test_command_list_with_group(self):
         arglist = [
-            '--group', 'common',
+            '--group',
+            'common',
         ]
         verifylist = [
             ('group', 'common'),
@@ -116,10 +116,7 @@ class TestCommandList(utils.TestCommand):
 
         collist = ('Command Group', 'Commands')
         self.assertEqual(collist, columns)
-        datalist = ((
-            'openstack.common',
-            'limits show\nextension list'
-        ),)
+        datalist = (('openstack.common', 'limits show\nextension list'),)
 
         self.assertEqual(datalist, tuple(data))
 
@@ -130,9 +127,8 @@ class TestCommandList(utils.TestCommand):
     clear=True,
 )
 class TestModuleList(utils.TestCommand):
-
     def setUp(self):
-        super(TestModuleList, self).setUp()
+        super().setUp()
 
         # Get the command object to test
         self.cmd = osc_module.ListModule(self.app, None)
